@@ -16,7 +16,7 @@ use Carp;
 
 requires 'submit';
 
-our $VERSION = '1.0.5'; # VERSION
+our $VERSION = '1.0.6'; # VERSION
 # ABSTRACT: Domain Availability API Calls
 
 sub check_domain_availability {
@@ -76,7 +76,7 @@ sub suggest_domain_names {
         phrase      => { isa => Str  },
         tlds        => { isa => Strs },
         hyphen      => { isa => Bool, optional => 1 },
-        related     => { isa => Bool, optional => 0 },
+        related     => { isa => Bool, default => 0 },
         num_results => { isa => Int,  default => 10 },
     );
 
